@@ -19,14 +19,20 @@
 #[macro_use]
 extern crate thiserror;
 
+#[macro_use]
+pub mod macros;
+
 pub mod errors;
 pub use errors::*;
 
-pub mod genesis;
-pub use genesis::*;
+pub mod global;
+pub use global::*;
 
-pub mod params;
-pub use params::*;
+pub mod testnet1;
 
 pub mod traits;
 pub use traits::*;
+
+pub mod prelude {
+    pub use crate::{errors::*, global::*, traits::*};
+}
